@@ -2,38 +2,15 @@
 #include <string>
 #include <fstream>
 #include <cstdint>
-//#define DEBUG_EXPORT_NFP
 
 #include <libnest2d/libnest2d.hpp>
 
 #include "../tools/printer_parts.hpp"
-#include "../tools/benchmark.h"
 #include "../tools/svgtools.hpp"
-#include "../tools/measure.hpp"
-
-#include <boost/rational.hpp>
-
-//#include "tools/libnfpglue.hpp"
-//#include "tools/nfp_svgnest_glue.hpp"
-
-#if ! defined(_MSC_VER) && defined(__SIZEOF_INT128__)
-namespace libnest2d { namespace nfp {
-template<class RawShape>
-struct NfpImpl<RawShape, NfpLevel::CONVEX_ONLY> {
-    NfpResult<RawShape> operator()(const RawShape& sh, const RawShape& other)
-    {
-        return nfpConvexOnly<RawShape, boost::rational<__int128>>(sh, other);
-    }
-};
-} // namespace nfp
-} // namespace libnest2d
-#endif
 
 using namespace libnest2d;
 
-namespace  {
-
-const std::vector<Item>& _parts(std::vector<Item>& ret, const TestData& data)
+static const std::vector<Item>& _parts(std::vector<Item>& ret, const TestData& data)
 {
     if(ret.empty()) {
         ret.reserve(data.size());
@@ -44,13 +21,11 @@ const std::vector<Item>& _parts(std::vector<Item>& ret, const TestData& data)
     return ret;
 }
 
-const std::vector<Item>& prusaParts() {
+static const std::vector<Item>& prusaParts() {
     static std::vector<Item> ret;
     return _parts(ret, PRINTER_PART_POLYGONS);
 }
 
-}
-
 int main(void /*int argc, char **argv*/) {
     
     std::vector<Item> input = prusaParts();
